#
# spec file for package ansible-runner
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ansible-runner
Version:        1.4.7
Release:        bp155.1.7
Summary:        Package for interfacing with Ansible
License:        Apache-2.0 AND GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/ansible/ansible-runner
Source:         https://files.pythonhosted.org/packages/source/a/ansible-runner/ansible-runner-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-PyYAML
BuildRequires:  python3-pexpect
BuildRequires:  python3-psutil
BuildRequires:  python3-python-daemon
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
Requires:       python3-PyYAML
Requires:       python3-pexpect >= 4.5
Requires:       python3-psutil
Requires:       python3-python-daemon
Requires:       python3-six >= 1.12
BuildArch:      noarch

%description
Ansible Runner is a tool and python library that helps when interfacing with
Ansible directly or as part of another system whether that be through a
container image interface, as a standalone tool, or as a Python module that
can be imported. The goal is to provide a stable and consistent interface
abstraction to Ansible. This allows Ansible to be embedded into other
systems that don’t want to manage the complexities of the interface on
their own (such as CI/CD platforms, Jenkins, or other automated tooling)

%prep
%setup -q

%build
%python3_build

%install
%python3_install
# dont polute the namespace with tests
rm -r %{buildroot}%{python3_sitelib}/test/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files
%doc README.md
%license LICENSE.md
%{_bindir}/ansible-runner
%{python3_sitelib}/ansible_runner
%{python3_sitelib}/ansible_runner-%{version}-py*.egg-info

%changelog
* Tue Apr 26 2022 pgajdos@suse.com
- do not require python-mock: the testsuite is not running anyway
  and newer testsuite (e. g. 2.1.3) will not use mock at all
  https://trello.com/c/S6eADbii/64-remove-python-mock
* Sun May 23 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.4.7
  * Fixed an issue where byte sequences in the output that are not
    interpretable as UTF-8 would break the job execution.
  * Fixed a bug that broke Ansible playbook execution prior to
    version 2.8 of Ansible
  * Fix an issue with --process_isoloation_*_ paths parsing cli args
  * Switch extravar format so we can support more than just string
    types
  * Make sure job events folder is created earlier to prevent
    errors when using immediately after starting a runner job
  * Annotate all runner_on events with start/end/duration times
- Drop 0001-Use-the-correct-python-executable-for-tests.patch
* Thu Feb 20 2020 Lars Vogdt <lars@linux-schulserver.de>
- update to 1.4.4:
  + Fix some unicode issues when using command line override on python 2.7
  + Fix an issue with file handles not closing on the pexpect pty
  + Fix missing ssh_key parameter from module interface
  + Fix a bug where the ssh agent process would hang around after
    process isolation exit causing a failure to remove temporary directories
  1.4.2 (2019-10-04)
  + Reverted ansible-runner --version to print a semantic version number
  1.4.1 (2019-10-03)
  + Fixed a bug that prevented ANSIBLE_HOST_KEY_CHECKING from being respected
  1.4.0 (2019-09-20)
  + Added changed count to stats data
  + Added initial support for gathering performance statistics using
    the system's cgroup interface
  + Fix command line args override missing from module run kwargs
  + Omit inventory argument entirely if no inventory content is supplied
    this allows ansible to pick up inventory from implicit locations and ansible.cfg
  + Fix an issue where Runner wouldn't properly clean up process
    isolation temporary directories
  + Fix error generated if unsafe parameter is used on vars prompt tasks
  + Fix an issue where additional callback plugins weren't being
    used when defined in the environment
  + Fix an issue where Runner would stop returning events after the
    playbook finished when using run_async
  + Fix an issue where unicode in task data would cause Runner to fail
  + Fix issues using vaulted data that would cause Runner to fail
  + Fix an issue where artifact-dir was only allowed in ad-hoc mode
- run fdupes
- remove upstreamed patch:
  0001-Use-the-correct-python-executable-for-tests.patch
- disable tests again for now
* Tue Jun  4 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 1.3.4:
  * make class __name__ match Ansible expectation
  * bundle six.ensure_str to avoid pinning to a new six version
  * Updating for 1.3.4 release
  * Adopt modified upstream packaging
  * Add missing lockfile RPM dependency
  * Fix an issue with missing options
  * port old callback tests to integration folder
  * Fix missing toplevel host events docs issue
  * Move integration data folder, add new test
- fix license - ansible-runner also contains code licensed under
  GPL-3.0-or-later
* Sat Apr 27 2019 Thomas Bechtold <tbechtold@suse.com>
- enable tests in %%check
- add 0001-Use-the-correct-python-executable-for-tests.patch to fix
  tests with python3
* Wed Apr 24 2019 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 1.3.3)
